%% Calculation of the compressive zone for strips of concrete panel %%

        %%% ----------------- DATA -------------------- %%%

                   %%% Lengths and dimensions %%%                

b=0.001;     %Unit width of concrete section$
l_y=12;      %Height/y-span of panel%
l_x=3;       %Width/x-span of panel%
t=0.3;       %Thickness of panel$
d_s=0.28;    %Distance from section surface to COG of ord. steel$
d_p=0.22;    %Distance from section surface to COG of pres. steel$
e=d_p-0.5*t; %Eccentricity relative to the COG for prestressing force%

A_p=(250*10^-6)/1000;     %Amount of prestressed reinforcement%
A_s=(510*10^-6)/1000;     %Amount of ordinary reinforcement%
A_sc=(510*10^-6)/1000;    %Amount of ordinary compressive reinforcement%


                    %%% Material properties %%%

E_p=195*10^9; %Modulus of elasticity prestressed reinforcement%
E_cm=35*10^9; %Modulus of elasticity concrete, C40%
E_s=200*10^9; %Modulus of elasticity ordinary reinforcement%

%---------------------------------------------------------------------%

         %%% ----------------- Loading ------------------ %%%

sigma_pmax=1360*10^6;   %Maximum steel stress from jacking%
N=sigma_pmax*A_p;       %Corresponding total prestressing force%
M_yp=N*e;               %Eccentricity moment due to prestressing%
M_yh=90;                %Max moment adopted from Etabs%
a=(M_yh-M_yp)/N;        %Equivalent arm for the total force%

%----------------------------------------------------------------------%

         %%% ----------- Calculation procedure ----------- %%%

etta1=E_p/E_cm;
etta2=E_s/E_cm;
    
i=0;  

for x=0.02:0.000001:0.5  %Iteration on the compressive zone%

i=i+1;
    
eq1=0.5*x*b-etta1*((d_p-x)/x)*A_p-etta2*((d_s-x)/x)*A_s ...
    +etta2*((d_s+x-t)/x)*A_sc;
sigma_c1(i)=N/eq1;

eq2=(1/(e+a))*(0.5*x*b*(d_p-(1/3)*x)+etta2*((d_s-x)/x)*A_s*(d_s-d_p) ...
    +etta2*((d_s+x-t)/x)*A_sc*(d_s+d_p-t));
sigma_c2(i)=N/eq2;

err(i)=abs(sigma_c1(i)-sigma_c2(i));

    if err(i) < 0.1*10^6  %Gives the error limit for the results%
        
        break

    end
    
end

x

%----------------------------------------------------------------------%

        %%% ----------- Post processing of results ----------- %%%

               %%% Stress-strain in steel and concrete top %%%

eps_c=sigma_c1(i)/E_cm;       %Strain at concrete top%
eps_s=((d_s-x)/x)*eps_c;      %Strain in ordinary reinforcement%
eps_sc=((d_s+x-t)/x)*eps_c;   %Strain in compressive reinforcement%
eps_p=((d_p-x)/x)*eps_c;      %Strain in prestressed reinforcement%

sigma_s=(eps_s*E_s)*10^-6;    %Corresponding stress in ord. steel%
sigma_sc=eps_sc*E_s;          %Corresponding stress in comp. steel%
sigma_p=eps_p*E_p;            %Corresponding stress in pres. steel%

sigma_c=((sigma_c1(i)+sigma_c2(i))/2)/10^6; %Stress at concrete top%


                           %%% Plot algoritms %%%

% scatter(0:50:400,sigma_c_3,'b')
% hold on
% xlabel('Amount of prestressed steel per unit width, A_p [mm^2/m]')
% ylabel('Stress [Mpa]')

% scatter(A_p*10^9,x*1000,'r')
% hold on
% xlabel('Amount of prestressed steel per unit width, A_p [mm^2/m]')
% ylabel('Height of compressive zone, x [mm]')







